pub enum OversizedAction {
Drop,
Truncate,
}Expand description
The behavior to apply when a frame exceeds the maximum allowed byte size.
Variants
Drop
Drop the entire oversized frame.
Truncate
Truncate the frame to the maximum allowed size and emit the partial content.
The remainder of the oversized frame is discarded up to the next delimiter.