pub struct CharacterDelimitedDecoderOptions {
pub delimiter: u8,
pub max_length: Option<usize>,
pub oversized_action: OversizedAction,
}Expand description
Options for building a CharacterDelimitedDecoder.
Fields
delimiter: u8The character that delimits byte sequences.
max_length: Option<usize>The maximum length of the byte buffer.
This length does not include the trailing delimiter.
By default, no maximum length is enforced. If events are malformed, this can lead to additional resource usage as events continue to be buffered in memory, and can potentially lead to memory exhaustion in extreme cases.
If there is a risk of processing malformed data, such as logs with user-controlled input, consider setting the maximum length to a reasonably large value as a safety net. This prevents processing from being unbounded.
oversized_action: OversizedActionThe behavior when a frame exceeds max_length.
When set to drop (the default), the entire oversized frame is discarded.
When set to truncate, the frame is truncated to max_length bytes and the
remainder is discarded up to the next delimiter.
This option has no effect if max_length is not set.
Implementations