pub struct NewlineDelimitedDecoderOptions {
pub max_length: Option<usize>,
pub oversized_action: OversizedAction,
}Expand description
Options for building a NewlineDelimitedDecoder.
Fields
max_length: Option<usize>The maximum length of the byte buffer.
This length does not include the trailing delimiter.
By default, no maximum length is enforced. If events are malformed, this can lead to additional resource usage as events continue to be buffered in memory, and can potentially lead to memory exhaustion in extreme cases.
If there is a risk of processing malformed data, such as logs with user-controlled input, consider setting the maximum length to a reasonably large value as a safety net. This prevents processing from being unbounded.
oversized_action: OversizedActionThe behavior when a line exceeds max_length.
When set to drop (the default), the entire oversized line is discarded.
When set to truncate, the line is truncated to max_length bytes and the
remainder is discarded up to the next newline.
This option has no effect if max_length is not set.
Implementations
Sourceimpl NewlineDelimitedDecoderOptions
impl NewlineDelimitedDecoderOptions
Sourcepub const fn new_with_max_length(max_length: usize) -> Self
pub const fn new_with_max_length(max_length: usize) -> Self
Creates a NewlineDelimitedDecoderOptions with a maximum frame length limit.